import { ConnectionBase, NodeBase } from '../types';
declare type PortId = string;
export declare class Socket {
    name: string;
    constructor(name: string);
}
export declare class Port<S extends Socket> {
    socket: S;
    label?: string;
    multipleConnections?: boolean;
    id: PortId;
    index?: number;
    constructor(socket: S, label?: string, multipleConnections?: boolean);
}
export declare class Input<S extends Socket> extends Port<S> {
    control: Control | null;
    showControl: boolean;
    addControl(control: Control): void;
    removeControl(): void;
}
export declare class Output<S extends Socket> extends Port<S> {
    constructor(socket: S, label?: string, multipleConnections?: boolean);
}
export declare class Control {
    id: string;
    index?: number;
    constructor();
}
declare type InputControlOptions<N> = {
    readonly?: boolean;
    initial?: N;
    change?: (value: N) => void;
};
export declare class InputControl<T extends 'text' | 'number', N = T extends 'text' ? string : number> extends Control {
    type: T;
    options?: InputControlOptions<N>;
    value?: N;
    readonly: boolean;
    constructor(type: T, options?: InputControlOptions<N>);
    setValue(value?: N): void;
}
export declare class Node<Inputs extends {
    [key in string]?: Socket;
} = {
    [key in string]?: Socket;
}, Outputs extends {
    [key in string]?: Socket;
} = {
    [key in string]?: Socket;
}, Controls extends {
    [key in string]?: Control;
} = {
    [key in string]?: Control;
}> implements NodeBase {
    label: string;
    id: NodeBase['id'];
    inputs: {
        [key in keyof Inputs]?: Input<Exclude<Inputs[key], undefined>>;
    };
    outputs: {
        [key in keyof Outputs]?: Output<Exclude<Outputs[key], undefined>>;
    };
    controls: Controls;
    selected?: boolean;
    constructor(label: string);
    hasInput<K extends keyof Inputs>(key: K): any;
    addInput<K extends keyof Inputs>(key: K, input: Input<Exclude<Inputs[K], undefined>>): void;
    removeInput(key: keyof Inputs): void;
    hasOutput<K extends keyof Outputs>(key: K): any;
    addOutput<K extends keyof Outputs>(key: K, output: Output<Exclude<Outputs[K], undefined>>): void;
    removeOutput(key: keyof Outputs): void;
    hasControl<K extends keyof Controls>(key: K): any;
    addControl<K extends keyof Controls>(key: K, control: Controls[K]): void;
    removeControl(key: keyof Controls): void;
}
export declare class Connection<Source extends Node, Target extends Node> implements ConnectionBase {
    sourceOutput: keyof Source['outputs'];
    targetInput: keyof Target['inputs'];
    id: ConnectionBase['id'];
    source: NodeBase['id'];
    target: NodeBase['id'];
    constructor(source: Source, sourceOutput: keyof Source['outputs'], target: Target, targetInput: keyof Target['inputs']);
}
export {};
//# sourceMappingURL=classic.d.ts.map